==> ec2-0.26.0-sources.jar: software/amazon/awscdk/services/ec2/VpcSubnetImportProps.java <==
package software.amazon.awscdk.services.ec2;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T12:57:55.145Z")
public interface VpcSubnetImportProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * The Availability Zone the subnet is located in
     */
    java.lang.String getAvailabilityZone();
    /**
     * The Availability Zone the subnet is located in
     */
    void setAvailabilityZone(final java.lang.String value);
    /**
     * The subnetId for this particular subnet
     */
    java.lang.String getSubnetId();
    /**
     * The subnetId for this particular subnet
     */
    void setSubnetId(final java.lang.String value);

    /**
     * @return a {@link Builder} of {@link VpcSubnetImportProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link VpcSubnetImportProps}
     */
    final class Builder {
        private java.lang.String _availabilityZone;
        private java.lang.String _subnetId;

        /**
         * Sets the value of AvailabilityZone
         * @param value The Availability Zone the subnet is located in
         * @return {@code this}
         */
        public Builder withAvailabilityZone(final java.lang.String value) {
            this._availabilityZone = java.util.Objects.requireNonNull(value, "availabilityZone is required");
            return this;
        }
        /**
         * Sets the value of SubnetId
         * @param value The subnetId for this particular subnet
         * @return {@code this}
         */
        public Builder withSubnetId(final java.lang.String value) {
            this._subnetId = java.util.Objects.requireNonNull(value, "subnetId is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link VpcSubnetImportProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public VpcSubnetImportProps build() {
            return new VpcSubnetImportProps() {
                private java.lang.String $availabilityZone = java.util.Objects.requireNonNull(_availabilityZone, "availabilityZone is required");
                private java.lang.String $subnetId = java.util.Objects.requireNonNull(_subnetId, "subnetId is required");

                @Override
                public java.lang.String getAvailabilityZone() {
                    return this.$availabilityZone;
                }

                @Override
                public void setAvailabilityZone(final java.lang.String value) {
                    this.$availabilityZone = java.util.Objects.requireNonNull(value, "availabilityZone is required");
                }

                @Override
                public java.lang.String getSubnetId() {
                    return this.$subnetId;
                }

                @Override
                public void setSubnetId(final java.lang.String value) {
                    this.$subnetId = java.util.Objects.requireNonNull(value, "subnetId is required");
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.VpcSubnetImportProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The Availability Zone the subnet is located in
         */
        @Override
        public java.lang.String getAvailabilityZone() {
            return this.jsiiGet("availabilityZone", java.lang.String.class);
        }

        /**
         * The Availability Zone the subnet is located in
         */
        @Override
        public void setAvailabilityZone(final java.lang.String value) {
            this.jsiiSet("availabilityZone", java.util.Objects.requireNonNull(value, "availabilityZone is required"));
        }

        /**
         * The subnetId for this particular subnet
         */
        @Override
        public java.lang.String getSubnetId() {
            return this.jsiiGet("subnetId", java.lang.String.class);
        }

        /**
         * The subnetId for this particular subnet
         */
        @Override
        public void setSubnetId(final java.lang.String value) {
            this.jsiiSet("subnetId", java.util.Objects.requireNonNull(value, "subnetId is required"));
        }
    }
}

==> ec2-0.27.0-sources.jar: software/amazon/awscdk/services/ec2/VpcSubnetImportProps.java <==
package software.amazon.awscdk.services.ec2;

@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-03-28T21:35:50.941Z")
public interface VpcSubnetImportProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * The Availability Zone the subnet is located in
     */
    java.lang.String getAvailabilityZone();
    /**
     * The subnetId for this particular subnet
     */
    java.lang.String getSubnetId();

    /**
     * @return a {@link Builder} of {@link VpcSubnetImportProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link VpcSubnetImportProps}
     */
    final class Builder {
        private java.lang.String _availabilityZone;
        private java.lang.String _subnetId;

        /**
         * Sets the value of AvailabilityZone
         * @param value The Availability Zone the subnet is located in
         * @return {@code this}
         */
        public Builder withAvailabilityZone(final java.lang.String value) {
            this._availabilityZone = java.util.Objects.requireNonNull(value, "availabilityZone is required");
            return this;
        }
        /**
         * Sets the value of SubnetId
         * @param value The subnetId for this particular subnet
         * @return {@code this}
         */
        public Builder withSubnetId(final java.lang.String value) {
            this._subnetId = java.util.Objects.requireNonNull(value, "subnetId is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link VpcSubnetImportProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public VpcSubnetImportProps build() {
            return new VpcSubnetImportProps() {
                private final java.lang.String $availabilityZone = java.util.Objects.requireNonNull(_availabilityZone, "availabilityZone is required");
                private final java.lang.String $subnetId = java.util.Objects.requireNonNull(_subnetId, "subnetId is required");

                @Override
                public java.lang.String getAvailabilityZone() {
                    return this.$availabilityZone;
                }

                @Override
                public java.lang.String getSubnetId() {
                    return this.$subnetId;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("availabilityZone", om.valueToTree(this.getAvailabilityZone()));
                    obj.set("subnetId", om.valueToTree(this.getSubnetId()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.VpcSubnetImportProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The Availability Zone the subnet is located in
         */
        @Override
        public java.lang.String getAvailabilityZone() {
            return this.jsiiGet("availabilityZone", java.lang.String.class);
        }

        /**
         * The subnetId for this particular subnet
         */
        @Override
        public java.lang.String getSubnetId() {
            return this.jsiiGet("subnetId", java.lang.String.class);
        }
    }
}
